package com.ruoyi.voluntary.mapper;

import java.util.List;
import com.ruoyi.voluntary.domain.BusiScoreLock;

/**
 * 志愿锁分Mapper接口
 * 
 * @author voluntary
 * @date 2022-11-29
 */
public interface BusiScoreLockMapper 
{
    /**
     * 查询志愿锁分
     * 
     * @param id 志愿锁分主键
     * @return 志愿锁分
     */
    public BusiScoreLock selectBusiScoreLockById(Long id);
    public BusiScoreLock selectBusiScoreLockByProvinceName(String provinceName);

    /**
     * 查询志愿锁分列表
     * 
     * @param busiScoreLock 志愿锁分
     * @return 志愿锁分集合
     */
    public List<BusiScoreLock> selectBusiScoreLockList(BusiScoreLock busiScoreLock);

    /**
     * 新增志愿锁分
     * 
     * @param busiScoreLock 志愿锁分
     * @return 结果
     */
    public int insertBusiScoreLock(BusiScoreLock busiScoreLock);

    /**
     * 修改志愿锁分
     * 
     * @param busiScoreLock 志愿锁分
     * @return 结果
     */
    public int updateBusiScoreLock(BusiScoreLock busiScoreLock);

    /**
     * 删除志愿锁分
     * 
     * @param id 志愿锁分主键
     * @return 结果
     */
    public int deleteBusiScoreLockById(Long id);

    /**
     * 批量删除志愿锁分
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBusiScoreLockByIds(Long[] ids);
}
